## Coding Style

Generic
-------

1. Four space indentation (no tabs).
2. Use single quotes for strings.
3. Keep lines shorter than 80 characters when possible.


Python
------

Follow the [PEP8](http://www.python.org/dev/peps/pep-0008/) Style Guide.

Most important things:

1. Separate top-level function and class definitions with two blank lines.
2. Method definitions inside a class are separated by a single blank line.
3. Use whitespace between comma seperated values.
4. Use white space between assignments and expressions (except parameter values).
5. Don't use whitespace before or after parentheses, brackets or braces.
6. Classes should use CamelCase naming.
7. Functions should use lowercase naming.
